# Rock [![Build Status](https://api.travis-ci.org/rockstack/rock.png?branch=master)](http://travis-ci.org/rockstack/rock)

This is a command line tool that simplifies creating, building, testing, and
running applications.

## License

This work is licensed under the MIT License (see the LICENSE file).
